@@ -17,7 +17,7 @@
 #include "builder.hpp"
 #include "def.hpp"
 #ifdef ZLIB_FOUND
-#include "zstr/zstr.hpp"
+#include "../extern/zstr/zstr.hpp"
 #endif
 
 // Cygwin doesn't come with an implementation for strdup if compiled with
@@ -350,8 +350,7 @@ void Reader::parseexpression(std::vector<ProcessedToken>::iterator& it,
 
     // const
     if (it->type == ProcessedTokenType::CONST) {
-      //	printf("LpReader: Offset change from %+g by %+g\n",
-      //expr->offset, it->value);
+      //      printf("LpReader: Offset change from %+g by %+g\n", expr->offset, it->value);
       expr->offset += it->value;
       ++it;
       continue;
@@ -858,7 +857,7 @@ void Reader::splittokens() {
     if (new_section_type) {
       // Section type change
       currentsection = it->keyword;
-      // Make sure the new section type has not occured previously
+      // Make sure the new section type has not occurred previously
       lpassert(sectiontokens.count(currentsection) == 0);
       // Remember the beginning of the new section: its the token
       // following the current one
